package com.hepia.backend.service;

import com.hepia.backend.model.dto.CreateTodoRequest;
import com.hepia.backend.model.entity.Todo;
import com.hepia.backend.repository.TodoRepository;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

import static org.springframework.http.HttpStatus.CREATED;

@Service
@RequiredArgsConstructor
public class TodoService {
    private final TodoRepository todoRepository;

    public ResponseEntity<List<Todo>> getAll() {
        List<Todo> todos = todoRepository.findAll();
        return ResponseEntity.ok(todos);
    }

    public ResponseEntity<Todo> create(CreateTodoRequest request) {
        Todo todo = Todo.builder().name(request.getName()).completed(false).build();
        Todo saved = todoRepository.save(todo);
        return ResponseEntity.status(CREATED).body(saved);
    }

    public ResponseEntity<Long> delete(Long id) {
        Optional<Todo> todo = todoRepository.findById(id);
        if (todo.isEmpty()) {
            return ResponseEntity.notFound().build();
        }

        todoRepository.deleteById(todo.get().getId());
        return ResponseEntity.ok(id);
    }

    public ResponseEntity<Todo> toggleCompleted(Long id) {
        Optional<Todo> todo = todoRepository.findById(id);
        if (todo.isEmpty()) {
            return ResponseEntity.notFound().build();
        }

        todo.get().setCompleted(!todo.get().isCompleted());
        Todo updated = todoRepository.save(todo.get());
        return ResponseEntity.ok(updated);
    }
}
