import { TodoService } from '@core/ports/todo.service';
import { Observable, of } from 'rxjs';
import { Todo, Todos } from '@core/models/todo';
import { TodoBuilder } from '@core/models/builder/todo.builder';

export class LocalStorageTodoService implements TodoService {
  add(todoName: string): Observable<Todo> {
    const todos = this.getTodos();
    const newTodo = new TodoBuilder()
      .withId(todos.length + 1)
      .withName(todoName)
      .uncomplete()
      .build();
    this.setTodos([...todos, newTodo]);
    return of(newTodo);
  }

  getAll(): Observable<Todos> {
    return of(this.getTodos());
  }

  remove(todoId: number): Observable<number> {
    const todos = this.getTodos().filter((todo) => todo.id !== todoId);
    this.setTodos(todos);
    return of(todoId);
  }

  toggleCompleted(todoId: number): Observable<Todo> {
    const todo = this.getTodos().find((todo) => todo.id === todoId)!;
    todo.completed = !todo.completed;
    const todos = this.getTodos().map((todo) => (todo.id === todoId ? { ...todo, completed: true } : todo));
    this.setTodos(todos);
    return of(todo);
  }

  private getTodos(): Todos {
    const todos = localStorage.getItem('todos');
    return todos ? JSON.parse(todos) : [];
  }

  private setTodos(todos: Todos): void {
    localStorage.setItem('todos', JSON.stringify(todos));
  }
}
