import { patchState, signalStore, withComputed, withHooks, withMethods, withState } from '@ngrx/signals';
import { Todos } from '@core/models/todo';
import { computed, inject } from '@angular/core';
import { TodoService } from '@core/ports/todo.service';
import { rxMethod } from '@ngrx/signals/rxjs-interop';
import { exhaustMap, pipe, switchMap, tap } from 'rxjs';

type TodoState = {
  todos: Todos;
  loading: boolean;
};

const initialState: TodoState = {
  todos: [],
  loading: false,
};

export const TodoStore = signalStore(
  withState<TodoState>(initialState),
  withComputed((store) => ({
    isLoading: computed(() => store.loading),
  })),
  withMethods((store, todoService = inject(TodoService)) => ({
    getAll: rxMethod<void>(
      pipe(
        tap(() => patchState(store, { loading: true })),
        switchMap(() => todoService.getAll()),
        tap((todos) => patchState(store, { todos, loading: false }))
      )
    ),

    add: rxMethod<string>(
      pipe(
        tap(() => patchState(store, { loading: true })),
        exhaustMap((todoName) => todoService.add(todoName)),
        tap((todo) => patchState(store, { todos: [...store.todos(), todo], loading: false }))
      )
    ),

    remove: rxMethod<number>(
      pipe(
        tap(() => patchState(store, { loading: true })),
        exhaustMap((id) => todoService.remove(id)),
        tap((id) => patchState(store, { todos: store.todos().filter((todo) => todo.id !== id), loading: false }))
      )
    ),

    toggleCompleted: rxMethod<number>(
      pipe(
        tap(() => patchState(store, { loading: true })),
        exhaustMap((id) => todoService.toggleCompleted(id)),
        tap((todo) =>
          patchState(store, { todos: store.todos().map((t) => (t.id === todo.id ? todo : t)), loading: false })
        )
      )
    ),
  })),
  withHooks((store) => ({
    onInit() {
      store.getAll();
    },
  }))
);
