import { Component, input, output, viewChild } from '@angular/core';
import { Todo } from '@core/models/todo';
import { FaIconComponent } from '@fortawesome/angular-fontawesome';
import { NgClass } from '@angular/common';
import { ModalConfirmComponent } from '@features/todo-list/components/modal-confirm.component';

@Component({
  selector: 'app-todo-list-item',
  template: `
    <li class="w-full bg-gray-50 p-3 rounded-lg shadow flex items-center justify-between gap-3">
      <label class="fieldset-label">
        <input type="checkbox" [checked]="todo().completed" class="checkbox" (change)="toggleCompleted.emit(todo())" />
        <span [ngClass]="{ 'line-through': todo().completed }" class="flex-grow ml-1">{{ todo().name }}</span>
      </label>
      <button class="btn btn-ghost btn-error ml-auto" (click)="modal()?.open()">
        <fa-icon [icon]="['fas', 'trash']"></fa-icon>
      </button>
    </li>

    <app-modal-confirm #confirmModal (confirm)="remove.emit(todo())" />
  `,
  imports: [FaIconComponent, NgClass, ModalConfirmComponent],
})
export class TodoListItemComponent {
  todo = input.required<Todo>();
  toggleCompleted = output<Todo>();
  remove = output<Todo>();
  modal = viewChild<ModalConfirmComponent>('confirmModal');
}
