import { ChangeDetectionStrategy, Component, inject } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { Todo } from '@core/models/todo';
import { AddTodoFormComponent } from '@features/todo-list/components/add-todo-form.component';
import { TodoListItemComponent } from '@features/todo-list/components/todo-list-item';
import { TodoStore } from '@core/todo.store';

@Component({
  selector: 'app-todo-list',
  imports: [FormsModule, AddTodoFormComponent, TodoListItemComponent, TodoListItemComponent],
  templateUrl: './todo-list.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
  providers: [TodoStore],
})
export default class TodoListComponent {
  protected readonly store = inject(TodoStore);

  addTodo(todoName: string) {
    if (!todoName) return;
    this.store.add(todoName);
  }

  toggleCompleted(todo: Todo) {
    this.store.toggleCompleted(todo.id);
  }

  remove(todo: Todo) {
    this.store.remove(todo.id);
  }
}
